@@ -9,7 +9,7 @@ def test_simple_flatten(settings_json_dict):
     flat = config.flatten()
     assert flat == {
         "database.connection.host": "localhost",
-        "database.connection.port": 5432
+        "database.connection.port": 5432,
     }
 
 
